==> localnews-base-model-2.0.11-sources.jar: com/bxm/localnews/common/vo/LocationRelation.java <==
package com.bxm.localnews.common.vo;

import java.io.Serializable;
import java.util.Date;

/**
 * c_location_relation
 *
 * @author
 */
public class LocationRelation implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 关联内容（微信分享语、朋友圈分享语）
     */
    private String content;

    /**
     * 类型（1、微信分享语，2：朋友圈分享语）
     */
    private Byte type;

    /**
     * 创建时间
     */
    private Date createTime;

    /**
     * 地区编号
     */
    private String locationCode;

    /**
     * 分享次数
     */
    private Integer shareTime;

    /**
     * 分享图片
     */
    private String imgUrl;

    /**
     * 分享描述
     */
    private String contentDescription;

    public Integer getShareTime() {
        return shareTime;
    }

    public void setShareTime(Integer shareTime) {
        this.shareTime = shareTime;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public Byte getType() {
        return type;
    }

    public void setType(Byte type) {
        this.type = type;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public String getLocationCode() {
        return locationCode;
    }

    public void setLocationCode(String locationCode) {
        this.locationCode = locationCode;
    }

    public String getImgUrl() {
        return imgUrl;
    }

    public void setImgUrl(String imgUrl) {
        this.imgUrl = imgUrl;
    }

    public String getContentDescription() {
        return contentDescription;
    }

    public void setContentDescription(String contentDescription) {
        this.contentDescription = contentDescription;
    }
}

==> localnews-base-model-3.8.0-sources.jar: com/bxm/localnews/common/vo/LocationRelation.java <==
package com.bxm.localnews.common.vo;

import java.io.Serializable;
import java.util.Date;

/**
 * c_location_relation
 *
 * @author
 */
public class LocationRelation implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 关联内容（微信分享语、朋友圈分享语）
     */
    private String content;

    /**
     * 类型（1、微信分享语，2：朋友圈分享语）
     */
    private Byte type;

    /**
     * 创建时间
     */
    private Date createTime;

    /**
     * 地区编号
     */
    private String locationCode;

    /**
     * 分享次数
     */
    private Integer shareTime;

    /**
     * 分享图片
     */
    private String imgUrl;

    /**
     * 分享描述
     */
    private String contentDescription;

    /**
     * H5分享详情
     */
    private String webShareDes;

    public Integer getShareTime() {
        return shareTime;
    }

    public void setShareTime(Integer shareTime) {
        this.shareTime = shareTime;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public Byte getType() {
        return type;
    }

    public void setType(Byte type) {
        this.type = type;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public String getLocationCode() {
        return locationCode;
    }

    public void setLocationCode(String locationCode) {
        this.locationCode = locationCode;
    }

    public String getImgUrl() {
        return imgUrl;
    }

    public void setImgUrl(String imgUrl) {
        this.imgUrl = imgUrl;
    }

    public String getContentDescription() {
        return contentDescription;
    }

    public void setContentDescription(String contentDescription) {
        this.contentDescription = contentDescription;
    }

    public String getWebShareDes() {
        return webShareDes;
    }

    public void setWebShareDes(String webShareDes) {
        this.webShareDes = webShareDes;
    }
}
